@@ -18,7 +18,7 @@
 #define LEARN_H 1
 
 #include "compiler.h"
-#include "ofp-errors.h"
+#include "openvswitch/ofp-errors.h"
 
 struct ds;
 struct flow;
@@ -30,7 +30,7 @@ struct nx_action_learn;
 
 /* NXAST_LEARN helper functions.
  *
- * See include/openflow/nicira-ext.h for NXAST_LEARN specification.
+ * See lib/ofp-actions.c for NXAST_LEARN specification.
  */
 
 enum ofperr learn_check(const struct ofpact_learn *, const struct flow *);
