@@ -285,6 +285,14 @@ nl_msg_put_u64(struct ofpbuf *msg, uint16_t type, uint64_t value)
     nl_msg_put_unspec(msg, type, &value, sizeof value);
 }
 
+/* Appends a Netlink attribute of the given 'type' and the given 128-bit host
+ * byte order 'value' to 'msg'. */
+void
+nl_msg_put_u128(struct ofpbuf *msg, uint16_t type, ovs_u128 value)
+{
+    nl_msg_put_unspec(msg, type, &value, sizeof value);
+}
+
 /* Appends a Netlink attribute of the given 'type' and the given 16-bit network
  * byte order 'value' to 'msg'. */
 void
@@ -309,6 +317,14 @@ nl_msg_put_be64(struct ofpbuf *msg, uint16_t type, ovs_be64 value)
     nl_msg_put_unspec(msg, type, &value, sizeof value);
 }
 
+/* Appends a Netlink attribute of the given 'type' and the given 128-bit
+ * network byte order 'value' to 'msg'. */
+void
+nl_msg_put_be128(struct ofpbuf *msg, uint16_t type, ovs_be128 value)
+{
+    nl_msg_put_unspec(msg, type, &value, sizeof value);
+}
+
 /* Appends a Netlink attribute of the given 'type' and the given IPv6
  * address order 'value' to 'msg'. */
 void
@@ -413,6 +429,14 @@ nl_msg_push_u64(struct ofpbuf *msg, uint16_t type, uint64_t value)
     nl_msg_push_unspec(msg, type, &value, sizeof value);
 }
 
+/* Prepends a Netlink attribute of the given 'type' and the given 128-bit host
+ * byte order 'value' to 'msg'. */
+void
+nl_msg_push_u128(struct ofpbuf *msg, uint16_t type, ovs_u128 value)
+{
+    nl_msg_push_unspec(msg, type, &value, sizeof value);
+}
+
 /* Prepends a Netlink attribute of the given 'type' and the given 16-bit
  * network byte order 'value' to 'msg'. */
 void
@@ -437,6 +461,14 @@ nl_msg_push_be64(struct ofpbuf *msg, uint16_t type, ovs_be64 value)
     nl_msg_push_unspec(msg, type, &value, sizeof value);
 }
 
+/* Prepends a Netlink attribute of the given 'type' and the given 128-bit
+ * network byte order 'value' to 'msg'. */
+void
+nl_msg_push_be128(struct ofpbuf *msg, uint16_t type, ovs_be128 value)
+{
+    nl_msg_push_unspec(msg, type, &value, sizeof value);
+}
+
 /* Prepends a Netlink attribute of the given 'type' and the given
  * null-terminated string 'value' to 'msg'. */
 void
@@ -464,7 +496,6 @@ void
 nl_msg_end_nested(struct ofpbuf *msg, size_t offset)
 {
     struct nlattr *attr = ofpbuf_at_assert(msg, offset, sizeof *attr);
-    ovs_assert(!nl_attr_oversized(msg->size - offset - NLA_HDRLEN));
     attr->nla_len = msg->size - offset;
 }
 
@@ -597,6 +628,16 @@ nl_attr_get_u64(const struct nlattr *nla)
     return get_32aligned_u64(x);
 }
 
+/* Returns the 128-bit host byte order value in 'nla''s payload.
+ *
+ * Asserts that 'nla''s payload is at least 16 bytes long. */
+ovs_u128
+nl_attr_get_u128(const struct nlattr *nla)
+{
+    const ovs_32aligned_u128 *x = nl_attr_get_unspec(nla, sizeof *x);
+    return get_32aligned_u128(x);
+}
+
 /* Returns the 16-bit network byte order value in 'nla''s payload.
  *
  * Asserts that 'nla''s payload is at least 2 bytes long. */
@@ -625,6 +666,16 @@ nl_attr_get_be64(const struct nlattr *nla)
     return get_32aligned_be64(x);
 }
 
+/* Returns the 128-bit network byte order value in 'nla''s payload.
+ *
+ * Asserts that 'nla''s payload is at least 16 bytes long. */
+ovs_be128
+nl_attr_get_be128(const struct nlattr *nla)
+{
+    const ovs_32aligned_be128 *x = nl_attr_get_unspec(nla, sizeof *x);
+    return get_32aligned_be128(x);
+}
+
 /* Returns the IPv6 address value in 'nla''s payload.
  *
  * Asserts that 'nla''s payload is at least 16 bytes long. */
@@ -672,6 +723,7 @@ min_attr_len(enum nl_attr_type type)
     case NL_A_U16: return 2;
     case NL_A_U32: return 4;
     case NL_A_U64: return 8;
+    case NL_A_U128: return 16;
     case NL_A_STRING: return 1;
     case NL_A_FLAG: return 0;
     case NL_A_IPV6: return 16;
@@ -691,6 +743,7 @@ max_attr_len(enum nl_attr_type type)
     case NL_A_U16: return 2;
     case NL_A_U32: return 4;
     case NL_A_U64: return 8;
+    case NL_A_U128: return 16;
     case NL_A_STRING: return SIZE_MAX;
     case NL_A_FLAG: return SIZE_MAX;
     case NL_A_IPV6: return 16;
