@@ -41,7 +41,7 @@
 
 VLOG_DEFINE_THIS_MODULE(timeval);
 
-#if !defined(HAVE_CLOCK_GETTIME)
+#if defined(_WIN32) || defined(__MACH__)
 typedef unsigned int clockid_t;
 static int clock_gettime(clock_t id, struct timespec *ts);
 
@@ -52,7 +52,7 @@ static int clock_gettime(clock_t id, struct timespec *ts);
 #ifndef CLOCK_REALTIME
 #define CLOCK_REALTIME 2
 #endif
-#endif /* !defined(HAVE_CLOCK_GETTIME) */
+#endif /* defined(_WIN32) || defined(__MACH__) */
 
 #ifdef _WIN32
 /* Number of 100 ns intervals from January 1, 1601 till January 1, 1970. */
@@ -71,10 +71,10 @@ struct clock {
     clockid_t id;               /* CLOCK_MONOTONIC or CLOCK_REALTIME. */
 
     /* Features for use by unit tests.  Protected by 'mutex'. */
-    struct ovs_mutex mutex;
     atomic_bool slow_path;             /* True if warped or stopped. */
-    struct timespec warp OVS_GUARDED;  /* Offset added for unit tests. */
     bool stopped OVS_GUARDED;          /* Disable real-time updates if true. */
+    struct ovs_mutex mutex;
+    struct timespec warp OVS_GUARDED;  /* Offset added for unit tests. */
     struct timespec cache OVS_GUARDED; /* Last time read from kernel. */
     struct large_warp large_warp OVS_GUARDED; /* Connection information waiting
                                                  for warp response. */
@@ -420,7 +420,7 @@ clock_gettime(clock_t id, struct timespec *ts)
 }
 #endif /* _WIN32 */
 
-#if defined(__MACH__) && !defined(HAVE_CLOCK_GETTIME)
+#ifdef __MACH__
 #include <mach/clock.h>
 #include <mach/mach.h>
 static int
